=============================
 Requirements-Builder v0.3.0
=============================

Requirements-Builder v0.3.0 was released on May 17, 2018.

About
-----

Build requirements files from setup.py requirements.

New features
~~~~~~~~~~~~

- Includes package extras in the generated result.

Bug fixes
---------

- Fixes ``~=`` selector output by including the minimum version
  additionally to the X.* specifier.

Installation
------------

   $ pip install requirements-builder==0.3.0

Documentation
-------------

   http://requirements-builder.readthedocs.io/

Happy hacking and thanks for flying Requirements-Builder.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/requirements-builder
|   URL: http://inveniosoftware.org
